# 1.2.0 (2023-01-15)
## Updated
Changed STATUS_INDUSI_BETRIEBSDATEN so that 500Hz and 1000Hz add option to be in more states per https://forum.zusi.de/viewtopic.php?p=342503#p342503

# 1.1.1 (2022-10-22)
## Updated
Docs on README and CHANGELOG to be consistent across tar and website

# 1.1.0 (2022-10-22)
## Added
Support for ETCS and ZBS messages

# 1.0.0 (2022-10-09)
## Initial release
Comes without support for ETCS and ZBS messages
